@@ -1,88 +1,9 @@
 """
-    Implementation of the [multicodec spec](https://github.com/multiformats/multicodec).
+    Implementation of the `multicodec spec <https://github.com/multiformats/multicodec>`_.
 
-    The `Multicodec` class provides a container for multicodec data:
+    Suggested usage:
 
-    ```py
     >>> from multiformats import multicodec
-    >>> from multiformats.multicodec import Multicodec
-    >>> Multicodec("identity", "multihash", 0x00, "permanent", "raw binary")
-    Multicodec(name='identity', tag='multihash', code=0,
-               status='permanent', description='raw binary')
-    ```
-
-    Core functionality is provided by the `get`, `exists`, `wrap` and `unwrap` functions.
-    The `get` and `exists` functions can be used to check whether a multicodec with given name or code is known,
-    and if so to get the corresponding object:
-
-    ```py
-    >>> multicodec.exists("identity")
-    True
-    >>> multicodec.exists(code=0x01)
-    True
-    >>> multicodec.get("identity")
-    Multicodec(name='identity', tag='multihash', code=0,
-               status='permanent', description='raw binary')
-    >>> multicodec.get(code=0x01)
-    Multicodec(name='cidv1', tag='cid', code=1,
-               status='permanent', description='CIDv1')
-    ```
-
-    The `wrap` and `unwrap` functions can be use to wrap raw binary data into multicodec data
-    (prepending the varint-encoded multicodec code) and to unwrap multicodec data into a pair
-    of multicodec and raw binary data:
-
-    ```py
-    >>> raw_data = bytes([192, 168, 0, 254])
-    >>> multicodec_data = wrap("ip4", raw_data)
-    >>> raw_data.hex()
-      'c0a800fe'
-    >>> multicodec_data.hex()
-    '04c0a800fe'
-    >>> varint.encode(0x04).hex()
-    '04' #       0x04 ^^^^ is the multicodec code for 'ip4'
-    >>> codec, raw_data = unwrap(multicodec_data)
-    >>> raw_data.hex()
-      'c0a800fe'
-    >>> codec
-    Multicodec(name='ip4', tag='multiaddr', code='0x04', status='permanent', description='')
-    ```
-
-    The `Multicodec.wrap` and `Multicodec.unwrap` methods perform analogous functionality
-    with an object-oriented API, additionally enforcing that the multicodec is being used to
-    unwrap the data is the multicodec that the data itself specifies:
-
-    ```py
-    >>> ip4 = multicodec.get("ip4")
-    >>> ip4
-    Multicodec(name='ip4', tag='multiaddr', code='0x04', status='permanent', description='')
-    >>> raw_data = bytes([192, 168, 0, 254])
-    >>> multicodec_data = ip4.wrap(raw_data)
-    >>> raw_data.hex()
-      'c0a800fe'
-    >>> multicodec_data.hex()
-    '04c0a800fe'
-    >>> varint.encode(0x04).hex()
-    '04' #       0x04 ^^^^ is the multicodec code for 'ip4'
-    >>> ip4.unwrap(multicodec_data).hex()
-      'c0a800fe'
-    >>> ip4.unwrap(bytes.fromhex('00c0a800fe')) # 'identity' multicodec data
-    multiformats.multicodec.err.ValueError: Found code 0x00 when unwrapping data, expected code 0x04.
-    ```
-
-    The `table` function can be used to iterate through known multicodecs, optionally restricting
-    to one or more tags and/or statuses:
-
-    ```py
-    >>> len(list(multicodec.table())) # multicodec.table() returns an iterator
-    482
-    >>> selected = multicodec.table(tag=["cid", "ipld", "multiaddr"], status="permanent")
-    >>> [m.code for m in selected]
-    [1, 4, 6, 41, 53, 54, 55, 56, 81, 85, 112, 113, 114, 120,
-     144, 145, 146, 147, 148, 149, 150, 151, 152, 176, 177,
-     178, 192, 193, 290, 297, 400, 421, 460, 477, 478, 479, 512]
-    ```
-
 """
 
 import importlib.resources as importlib_resources
@@ -96,7 +17,8 @@ from typing_validation import validate
 
 from multiformats import varint
 from multiformats.varint import BytesLike
-from . import err
+# from . import err
+from .err import MulticodecKeyError, MulticodecValueError
 
 def _hexcode(code: int) -> str:
     hexcode = hex(code)
@@ -110,14 +32,22 @@ class Multicodec:
 
         Example usage:
 
-        ```py
-            >>> Multicodec(**{
-            ...     'name': 'cidv1', 'tag': 'cid', 'code': '0x01',
-            ...     'status': 'permanent', 'description': 'CIDv1'})
-            Multicodec(name='cidv1', tag='cid', code=1,
-                       status='permanent', description='CIDv1')
-        ```
+        >>> Multicodec(**{
+        ...     'name': 'cidv1', 'tag': 'cid', 'code': '0x01',
+        ...     'status': 'permanent', 'description': 'CIDv1'})
+        Multicodec(name='cidv1', tag='cid', code=1,
+                   status='permanent', description='CIDv1')
 
+        :param name: the multicodec name
+        :type name: :obj:`str`
+        :param tag: the multicodec tag
+        :type tag: :obj:`str`
+        :param code: the multicodec code, as integer or ``0xYZ`` hex-string
+        :type code: :obj:`int` or :obj:`str`
+        :param status: the multicodec status
+        :type status: ``'draft'`` or ``'permanent'``, *optional*
+        :param description: the multicodec description
+        :type description: :obj:`str`, *optional*
     """
 
     _name: str
@@ -150,26 +80,32 @@ class Multicodec:
     @staticmethod
     def _validate_name(name: str) -> str:
         if not re.match(r"^[a-z][a-z0-9_-]+$", name):
-            raise err.ValueError(f"Invalid multicodec name {repr(name)}")
+            raise MulticodecValueError(f"Invalid multicodec name {repr(name)}")
         return name
 
     @staticmethod
     def validate_code(code: Union[int, str]) -> int:
         """
-            Validates a multibase code and transforms it to unsigned integer format (if in hex format).
+            Validates a multicodec code and transforms it to unsigned integer format (if in hex format).
+
+            :param code: the multicodec code, as integer or `0xYZ` hex-string
+            :type code: :obj:`int` or :obj:`str`
+
+            :raises ValueError: if the code is invalid
+
         """
         if isinstance(code, str):
             if code.startswith("0x"):
                 code = code[2:]
             code = int(code, base=16)
         if code < 0:
-            raise err.ValueError(f"Invalid multicodec code {repr(code)}.")
+            raise MulticodecValueError(f"Invalid multicodec code {repr(code)}.")
         return code
 
     @staticmethod
     def _validate_status(status: str) -> Literal["draft", "permanent"]:
         if status not in ("draft", "permanent"):
-            raise err.ValueError(f"Invalid multicodec status {repr(status)}.")
+            raise MulticodecValueError(f"Invalid multicodec status {repr(status)}.")
         return cast(Literal["draft", "permanent"], status)
 
     @property
@@ -177,9 +113,9 @@ class Multicodec:
         """
             Multicodec name. Must satisfy the following:
 
-            ```py
-            re.match(r"^[a-z][a-z0-9_-]+$", name)
-            ```
+            .. code-block:: python
+
+                re.match(r"^[a-z][a-z0-9_-]+$", name)
         """
         return self._name
 
@@ -200,13 +136,12 @@ class Multicodec:
 
             Example usage:
 
-            ```py
             >>> m = multicodec.get(1)
             >>> m.code
             1
             >>> m.hexcode
             '0x01'
-            ```
+
         """
         return _hexcode(self._code)
 
@@ -224,7 +159,7 @@ class Multicodec:
     def is_private_use(self) -> bool:
         """
             Whether this multicodec code is reserved for private use,
-            i.e. whether it is in `range(0x300000, 0x400000)`.
+            i.e. whether it is in ``range(0x300000, 0x400000)``.
         """
         return self.code in range(0x300000, 0x400000)
 
@@ -232,13 +167,12 @@ class Multicodec:
         """
             Wraps raw binary data into multicodec data:
 
-            ```
-            <raw data> -> <code><raw data>
-            ```
+            .. code-block:: console
+
+                <raw data> --> <code><raw data>
 
             Example usage:
 
-            ```py
             >>> ip4 = multicodec.get("ip4")
             >>> ip4
             Multicodec(name='ip4', tag='multiaddr', code='0x04', status='permanent', description='')
@@ -250,7 +184,12 @@ class Multicodec:
             '04c0a800fe'
             >>> varint.encode(0x04).hex()
             '04' #       0x04 ^^^^ is the multicodec code for 'ip4'
-            ```
+
+            :param raw_data: the raw data to be wrapped
+            :type raw_data: :obj:`~multiformats.varint.BytesLike`
+
+            :raise ValueError: see :func:`~multiformats.varint.encode`
+
         """
         return varint.encode(self.code)+raw_data
 
@@ -258,16 +197,15 @@ class Multicodec:
         """
             Unwraps multicodec binary data to raw data:
 
-            ```
-            <code><raw data> -> <raw data>
-            ```
+            .. code-block::
+
+                <code><raw data> --> <raw data>
 
             Additionally checks that the code listed by the data
             matches the code of this multicodec.
 
             Example usage:
 
-            ```py
             >>> multicodec_data = bytes.fromhex("c0a800fe")
             >>> raw_data = ip4.unwrap(multicodec_data)
             >>> multicodec_data.hex()
@@ -276,13 +214,19 @@ class Multicodec:
               'c0a800fe'
             >>> varint.encode(0x04).hex()
             '04' #       0x04 ^^^^ is the multicodec code for 'ip4'
-            ```
+
+            :param multicodec_data: the multicodec data to be unwrapped
+            :type multicodec_data: :obj:`~multiformats.varint.BytesLike`
+
+            :raise ValueError: if the unwrapped multicodec code does not match this multicodec's code
+            :raise ValueError: see :func:`multiformats.multicodec.unwrap_raw`
+            :raise KeyError: see :func:`multiformats.multicodec.unwrap_raw`
         """
         code, _, raw_data = unwrap_raw(multicodec_data)
         # code, _, raw_data = varint.decode_raw(multicodec_data)
         if code != self.code:
             hexcode = _hexcode(code)
-            raise err.ValueError(f"Found code {hexcode} when unwrapping data, expected code {self.hexcode}.")
+            raise MulticodecValueError(f"Found code {hexcode} when unwrapping data, expected code {self.hexcode}.")
         return bytes(raw_data)
 
     def to_json(self) -> Mapping[str, str]:
@@ -291,12 +235,11 @@ class Multicodec:
 
             Example usage:
 
-            ```py
             >>> m = multicodec.get(1)
             >>> m.to_json()
             {'name': 'cidv1', 'tag': 'cid', 'code': '0x01',
              'status': 'permanent', 'description': 'CIDv1'}
-            ```
+
         """
         return {
             "name": self.name,
@@ -332,71 +275,84 @@ class Multicodec:
 def get(name: Optional[str] = None, *, code: Optional[int] = None) -> Multicodec:
     """
         Gets the multicodec with given name or code.
-        Raises `err.KeyError` if no such multicodec exists.
-        Exactly one of `name` and `code` must be specified.
 
         Example usage:
 
-        ```py
         >>> multicodec.get("identity")
         Multicodec(name='identity', tag='multihash', code=0,
                    status='permanent', description='raw binary')
         >>> multicodec.get(code=0x01)
         Multicodec(name='cidv1', tag='ipld', code=1,
                    status='permanent', description='CIDv1')
-        ```
+
+        :param name: the multicodec name
+        :type name: :obj:`str` or :obj:`None`, *optional*
+        :param code: the multicodec code
+        :type code: :obj:`int` or :obj:`None`, *optional*
+
+        :raises KeyError: if no such multicodec exists
+        :raises ValueError: unless exactly one of ``name`` and ``code`` is specified
     """
     validate(name, Optional[str])
     validate(code, Optional[int])
     if (name is None) == (code is None):
-        raise err.ValueError("Must specify exactly one between 'name' and 'code'.")
+        raise MulticodecValueError("Must specify exactly one between 'name' and 'code'.")
     if name is not None:
         if name not in _name_table:
-            raise err.KeyError(f"No multicodec named {repr(name)}.")
+            raise MulticodecKeyError(f"No multicodec named {repr(name)}.")
         return _name_table[name]
     if code not in _code_table:
-        raise err.KeyError(f"No multicodec with code {repr(code)}.")
+        raise MulticodecKeyError(f"No multicodec with code {repr(code)}.")
     return _code_table[code]
 
 
 def multicodec(name: str, *, tag: Optional[str] = None) -> Multicodec:
     """
-        An alias for `get`, for use with multicodec name only.
+        An alias for :func:`get`, for use with multicodec name only.
         If a tag is passed, ensures that the multicodec tag matches the one given.
 
         Example usage:
 
-        ```py
         >>> from multiformats.multicodec import multicodec
         >>> multicodec("identity")
         Multicodec(name='identity', tag='multihash', code=0,
                    status='permanent', description='raw binary')
-        ```
+
+        :param name: the multicodec name
+        :type name: :obj:`str`
+        :param tag: the optional multicodec tag
+        :type tag: :obj:`str` or :obj:`None`, *optional*
+
+        :raises KeyError: see :func:`get`
     """
     codec = get(name)
     if tag is not None and codec.tag != tag:
-        raise err.KeyError(f"Multicodec {repr(name)} exists, but its tag is not {repr(tag)}.")
+        raise MulticodecKeyError(f"Multicodec {repr(name)} exists, but its tag is not {repr(tag)}.")
     return codec
 
 
 def exists(name: Union[None, str, Multicodec] = None, *, code: Optional[int] = None) -> bool:
     """
         Checks whether there is a multicodec with the given name or code.
-        Exactly one of `name` and `code` must be specified.
 
         Example usage:
 
-        ```py
         >>> multicodec.exists("identity")
         True
         >>> multicodec.exists(code=0x01)
         True
-        ```
+
+        :param name: the multicodec name
+        :type name: :obj:`str` or :obj:`None`, *optional*
+        :param code: the multicodec code
+        :type code: :obj:`int` or :obj:`None`, *optional*
+
+        :raises ValueError: unless exactly one of ``name`` and ``code`` is specified
     """
     validate(name, Optional[str])
     validate(code, Optional[int])
     if (name is None) == (code is None):
-        raise err.ValueError("Must specify exactly one between 'name' and 'code'.")
+        raise MulticodecValueError("Must specify exactly one between 'name' and 'code'.")
     if name is not None:
         return name in _name_table
     return code in _code_table
@@ -406,13 +362,12 @@ def wrap(codec: Union[str, int, Multicodec], raw_data: BytesLike) -> bytes:
     """
         Wraps raw binary data into multicodec data:
 
-        ```
-        <raw data> -> <code><raw data>
-        ```
+        .. code-block::
 
-            Example usage:
+            <raw data> --> <code><raw data>
+
+        Example usage:
 
-        ```py
         >>> raw_data = bytes([192, 168, 0, 254])
         >>> multicodec_data = multicodec.wrap("ip4", raw_data)
         >>> raw_data.hex()
@@ -421,7 +376,13 @@ def wrap(codec: Union[str, int, Multicodec], raw_data: BytesLike) -> bytes:
         '04c0a800fe'
         >>> varint.encode(0x04).hex()
         '04' #       0x04 ^^^^ is the multicodec code for 'ip4'
-        ```
+
+        :param codec: the multicodec that the raw data refers to
+        :type codec: :obj:`str`, :obj:`int` or :class:`Multicodec`
+        :param raw_data: the raw binary data
+        :type raw_data: :obj:`~multiformats.varint.BytesLike`
+
+        :raises KeyError: see :func:`get`
     """
     if isinstance(codec, str):
         codec = get(codec)
@@ -437,8 +398,7 @@ def unwrap(multicodec_data: BytesLike) -> Tuple[Multicodec, bytes]:
 
         Example usage:
 
-        ```py
-        >>> multicodec_data = bytes.fromhex("c0a800fe")
+        >>> multicodec_data = bytes.fromhex("04c0a800fe")
         >>> codec, raw_data = multicodec.unwrap(multicodec_data)
         >>> multicodec_data.hex()
         '04c0a800fe'
@@ -446,7 +406,11 @@ def unwrap(multicodec_data: BytesLike) -> Tuple[Multicodec, bytes]:
           'c0a800fe'
         >>> codec
         Multicodec(name='ip4', tag='multiaddr', code='0x04', status='permanent', description='')
-        ```
+
+        :param multicodec_data: the binary data prefixed with multicodec code
+        :type multicodec_data: :obj:`~multiformats.varint.BytesLike`
+
+        :raises KeyError: if the code does not correspond to a know multicodec
     """
     code, _, raw_data = unwrap_raw(multicodec_data)
     return get(code=code), bytes(raw_data)
@@ -464,71 +428,101 @@ def unwrap_raw(multicodec_data: _BufferedIOT) -> Tuple[int, int, _BufferedIOT]:
 
 def unwrap_raw(multicodec_data: Union[BytesLike, BufferedIOBase]) -> Tuple[int, int, Union[memoryview, BufferedIOBase]]:
     """
-        An alias for `multiformats.varint.decode_raw`, returning a triple of multicodec code, bytes read and remaining bytes.
-        The multicodec code is validated, and `err.KeyError` is raised if not multicodec with such code exists.
-    """
-    code, n, raw_data = varint.decode_raw(multicodec_data)
-    if not exists(code=code):
-        raise err.KeyError(f"No multicodec is known with unwrapped code {_hexcode(code)}.")
-    return code, n, raw_data
-
-
-def validate_multicodec(multicodec: Multicodec) -> None:
-    """
-        Validates a multicodec:
-
-        - raises `err.KeyError` if no multicodec with the given name is registered
-        - raises `err.ValueError` if a multicodec with the given name is registered, but is different from the one given
-        - raises no error if the given multicodec is registered
-    """
-    validate(multicodec, Multicodec)
-    mc = get(multicodec.name)
-    if mc != multicodec:
-        raise err.ValueError(f"Multicodec named {multicodec.name} exists, but is not the one given.")
-
-def register(m: Multicodec, *, overwrite: bool = False) -> None:
-    """
-        Registers a given multicodec. The optional keyword argument `overwrite` (default: `False`)
-        can be used to overwrite a multicodec with existing code.
-
-        When `overwrite` is `False`, raises `err.ValueError` if a multicodec with the same name or code already exists.
-        When `overwrite` is `True`, raises `err.ValueError` if a multicodec with the same name but different code already exists.
+        Similar to :func:`unwrap`, but returns a triple of multicodec code, number of bytes read and remaining bytes.
 
         Example usage:
 
-        ```py
-            >>> m = Multicodec("my-multicodec", "my-tag", 0x300001, "draft", "...")
-            >>> multicodec.register(m)
-            >>> multicodec.exists(code=0x300001)
-            True
-            >>> multicodec.get(code=0x300001).name
-            'my-multicodec'
-            >>> multicodec.get(code=0x300001).is_private_use
-            True
-        ```
+        >>> multicodec_data = bytes.fromhex("04c0a800fe")
+        >>> code, num_bytes_read, remaining_bytes = multicodec.unwrap_raw(multicodec_data)
+        >>> code
+        4
+        >>> num_bytes_read
+        1
+        >>> remaining_bytes
+        <memory at 0x000001BE46B17640>
+        >>> multicodec_data.hex()
+        '04c0a800fe'
+        >>> bytes(remaining_bytes).hex()
+          'c0a800fe'
+
+        :param multicodec_data: the binary data prefixed with multicodec code
+        :type multicodec_data: :obj:`~multiformats.varint.BytesLike`
+
+        :raises KeyError: if the code does not correspond to a know multicodec
     """
-    validate(m, Multicodec)
+    code, n, raw_data = varint.decode_raw(multicodec_data)
+    if not exists(code=code):
+        raise MulticodecKeyError(f"No multicodec is known with unwrapped code {_hexcode(code)}.")
+    return code, n, raw_data
+
+
+def validate_multicodec(codec: Multicodec) -> None:
+    """
+        Validates an instance of :class:`Multicodec`.
+        If the multicodec is registered (i.e. valid), no error is raised.
+
+        :param codec: the instance to be validated
+        :type codec: :class:`Multicodec`
+
+        :raises KeyError: if no multicodec with the given name is registered
+        :raises ValueError: if a multicodec with the given name is registered, but is different from the one given
+
+    """
+    validate(codec, Multicodec)
+    mc = get(codec.name)
+    if mc != codec:
+        raise MulticodecValueError(f"Multicodec named {codec.name} exists, but is not the one given.")
+
+def register(codec: Multicodec, *, overwrite: bool = False) -> None:
+    """
+        Registers a given multicodec.
+
+        Example usage:
+
+        >>> m = Multicodec("my-multicodec", "my-tag", 0x300001, "draft", "...")
+        >>> multicodec.register(m)
+        >>> multicodec.exists(code=0x300001)
+        True
+        >>> multicodec.get(code=0x300001).name
+        'my-multicodec'
+        >>> multicodec.get(code=0x300001).is_private_use
+        True
+
+        :param codec: the multicodec to register
+        :type codec: :class:`Multicodec`
+        :param overwrite: whether to overwrite a multicodec with existing code (optional, default :obj:`False`)
+        :type overwrite: :obj:`bool`, *optional*
+
+        :raises ValueError: if ``overwrite`` is :obj:`False` and a multicodec with the same name or code already exists
+        :raises ValueError: if ``overwrite`` is :obj:`True` and a multicodec with the same name but different code already exists
+    """
+    validate(codec, Multicodec)
     validate(overwrite, bool)
-    if not overwrite and m.code in _code_table:
-        raise err.ValueError(f"Multicodec with code {repr(m.code)} already exists: {_code_table[m.code]}")
-    if m.name in _name_table and _name_table[m.name].code != m.code:
-        raise err.ValueError(f"Multicodec with name {repr(m.name)} already exists: {_name_table[m.name]}")
-    _code_table[m.code] = m
-    _name_table[m.name] = m
+    if not overwrite and codec.code in _code_table:
+        raise MulticodecValueError(f"Multicodec with code {repr(codec.code)} already exists: {_code_table[codec.code]}")
+    if codec.name in _name_table and _name_table[codec.name].code != codec.code:
+        raise MulticodecValueError(f"Multicodec with name {repr(codec.name)} already exists: {_name_table[codec.name]}")
+    _code_table[codec.code] = codec
+    _name_table[codec.name] = codec
 
 
 def unregister(name: Optional[str] = None, *, code: Optional[int] = None) -> None:
     """
         Unregisters the multicodec with given name or code.
-        Raises `err.KeyError` if no such multicodec exists.
 
         Example usage:
 
-        ```py
         >>> multicodec.unregister(code=0x01) # cidv1
         >>> multicodec.unregister(code=0x01)
         False
-        ```
+
+        :param name: the multicodec name
+        :type name: :obj:`str` or :obj:`None`, *optional*
+        :param code: the multicodec code
+        :type code: :obj:`int` or :obj:`None`, *optional*
+
+        :raises KeyError: if no such multicodec exists
+        :raises ValueError: unless exactly one of ``name`` and ``code`` is specified
     """
     m = get(name, code=code)
     del _code_table[m.code]
@@ -541,13 +535,9 @@ def table(*,
           status: Union[None, str, AbstractSet[str], Sequence[str]] = None) -> Iterator[Multicodec]:
     """
         Iterates through the registered multicodecs, in order of ascending code.
-        The optional keyword arguments `tag` and `status` can be used to restrict the iterator
-        to multicodecs with a given `tag` or `status` respectively.
 
         Example usage:
 
-
-        ```py
         >>> len(list(multicodec.table())) # multicodec.table() returns an iterator
         482
         >>> selected = multicodec.table(tag=["cid", "cid", "multiaddr"], status="permanent")
@@ -555,7 +545,12 @@ def table(*,
         [1, 4, 6, 41, 53, 54, 55, 56, 81, 85, 112, 113, 114, 120,
          144, 145, 146, 147, 148, 149, 150, 151, 152, 176, 177,
          178, 192, 193, 290, 297, 400, 421, 460, 477, 478, 479, 512]
-        ```
+
+        :param tag: one or more tags to be selected (if :obj:`None`, all tags are included)
+        :type tag: :obj:`None`, :obj:`str`, set or sequence of :obj:`str`, *optional*
+        :param status: one or more statuses to be selected (if :obj:`None`, all statuses are included)
+        :type status: :obj:`None`, :obj:`str`, set or sequence of :obj:`str`, *optional*
+
     """
     validate(tag, Union[None, str, AbstractSet[str], Sequence[str]])
     validate(status, Union[None, str, AbstractSet[str], Sequence[str]])
@@ -582,62 +577,58 @@ def table(*,
         yield m
 
 
-def build_multicodec_tables(multicodecs: Iterable[Multicodec], *,
+def build_multicodec_tables(codecs: Iterable[Multicodec], *,
                             allow_private_use: bool = False) -> Tuple[Dict[int, Multicodec], Dict[str, Multicodec]]:
     """
         Creates code->multicodec and name->multicodec mappings from a finite iterable of multicodecs,
         returning the mappings.
-        The keyword argument `allow_private_use` (default: `False`) can be used to allow multicodec entries
-        with private use codes in `range(0x300000, 0x400000)`: if set to `False`, a `err.ValueError` is raised
-        if one such private use code is encountered.
-
-        Raises `err.ValueError` if the same multicodec code is encountered multiple times, unless exactly one
-        of the multicodecs has permanent status (in which case that codec is the one inserted in the table).
-        Raises `err.ValueError` if the same name is encountered multiple times.
 
         Example usage:
 
-        ```py
-            code_table, name_table = build_multicodec_tables(multicodecs)
-        ```
+        >>> code_table, name_table = build_multicodec_tables(codecs)
+
+        :param codecs: multicodecs to be registered
+        :type codecs: iterable of :class:`Multicodec`
+        :param allow_private_use: whether to allow multicodec entries with private use codes in ``range(0x300000, 0x400000)`` (default :obj:`False`)
+        :type allow_private_use: :obj:`bool`, *optional*
+
+        :raises ValueError: if ``allow_private_use`` and a multicodec with private use code is encountered
+        :raises ValueError: if the same multicodec code is encountered multiple times, unless exactly one of the multicodecs
+        has permanent status (in which case that codec is the one inserted in the table)
+        :raises ValueError: if the same name is encountered multiple times
+
     """
-    # validate(multicodecs, Iterable[Multicodec]) # TODO: not yet properly supported by typing-validation
+    # validate(codecs, Iterable[Multicodec]) # TODO: not yet properly supported by typing-validation
     validate(allow_private_use, bool)
     code_table: Dict[int, Multicodec] = {}
     name_table: Dict[str, Multicodec] = {}
     overwritten_draft_codes: Set[int] = set()
-    for m in multicodecs:
+    for m in codecs:
         if not allow_private_use and m.is_private_use:
-            raise err.ValueError(f"Private use multicodec not allowed: {m}")
+            raise MulticodecValueError(f"Private use multicodec not allowed: {m}")
         if m.code in code_table:
             if code_table[m.code].status == "permanent":
                 if m.status == "draft":
                     # this draft code has been superseded by a permanent one, skip it
                     continue
-                raise err.ValueError(f"Multicodec code {m.hexcode} appears multiple times in table.")
+                raise MulticodecValueError(f"Multicodec code {m.hexcode} appears multiple times in table.")
             if m.status != "permanent":
                 # overwriting draft code with another draft code: dodgy, need to check at the end
                 overwritten_draft_codes.add(m.code)
         code_table[m.code] = m
         if m.name in name_table:
-            raise err.ValueError(f"Multicodec name {m.name} appears multiple times in table.")
+            raise MulticodecValueError(f"Multicodec name {m.name} appears multiple times in table.")
         name_table[m.name] = m
     for code in overwritten_draft_codes:
         m = code_table[code]
         if m.status != "permanent":
-            raise err.ValueError(f"Code {m.code} appears multiple times in table, "
+            raise MulticodecValueError(f"Code {m.code} appears multiple times in table, "
                               "but none of the associated multicodecs is permanent.")
     return code_table, name_table
 
 # Create the global code->multicodec and name->multicodec mappings.
 _code_table: Dict[int, Multicodec]
 _name_table: Dict[str, Multicodec]
-with importlib_resources.open_text("multiformats.multicodec", "multicodec-table.json") as table_f:
-    table_json = json.load(table_f)
-    _code_table, _name_table = build_multicodec_tables(Multicodec(**row) for row in table_json)
-
-
-# additional docs info
-__pdoc__ = {
-    "build_multicodec_tables": False # exclude from docs
-}
+with importlib_resources.open_text("multiformats.multicodec", "multicodec-table.json") as _table_f:
+    _table_json = json.load(_table_f)
+    _code_table, _name_table = build_multicodec_tables(Multicodec(**row) for row in _table_json)
